changeset 56:333f98d045ab

FIX: Remove the port information from a cleaned path url also
author Franz Glasner <hg@dom66.de>
date Wed, 22 Nov 2017 11:45:30 +0100
parents fc8dbbe5f37f
children f0c476047c29
files extensions/kwarchive.py
diffstat 1 files changed, 2 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/extensions/kwarchive.py	Sun Nov 19 17:09:14 2017 +0100
+++ b/extensions/kwarchive.py	Wed Nov 22 11:45:30 2017 +0100
@@ -311,6 +311,7 @@
                     path_url.user = None
                     path_url.passwd = None
                     path_url.host = stripped_hostname(path_url.host)
+                    path_url.port = None
                     path_uri = bytes(path_url)
                 else:
                     path_uri = util.hidepassword(ui.paths[hgpath].loc)
@@ -329,7 +330,7 @@
 
 
 def stripped_hostname(hostname):
     """Return `hostname` without any domain information"""
     if not hostname:
         return hostname
     idx = hostname.find('.')
@@ -329,7 +330,7 @@
 
 def stripped_hostname(hostname):
-    """Return `hostname` without any domain information"""
+    """Return `hostname` without any domain port information"""
     if not hostname:
         return hostname